@@ -1,11 +1,12 @@
 package Net::Kubernetes;
+$Net::Kubernetes::VERSION = '1.05';
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '1.04';
+
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
 require HTTP::Request;
-require URI;;
+require URI;
 require Throwable::Error;
 use MIME::Base64;
 require Net::Kubernetes::Exception;
@@ -16,122 +17,137 @@ with 'Net::Kubernetes::Role::ResourceFetcher';
 
 
 has 'default_namespace' => (
-	is         => 'rw',
-	isa        => 'Net::Kubernetes::Namespace',
-	required   => 0,
-	lazy       => 1,
-	handles    => [qw(
-		build_secret create create_from_file get_deployment get_pod
-		get_rc get_replica_set get_replication_controller get_rs
-		get_secret get_service list_deployments list_endpoints
-		list_events list_pods list_rc list_replica_sets
-		list_replication_controllers list_rs list_secrets list_services
-	)],
-	builder    => '_get_default_namespace',
+    is       => 'rw',
+    isa      => 'Net::Kubernetes::Namespace',
+    required => 0,
+    lazy     => 1,
+    handles  => [
+        qw(
+            build_secret create create_from_file get_deployment get_pod
+            get_rc get_replica_set get_replication_controller get_rs
+            get_secret get_service list_deployments list_endpoints
+            list_events list_pods list_rc list_replica_sets
+            list_replication_controllers list_rs list_secrets list_services
+            )
+    ],
+    builder => '_get_default_namespace',
 );
 
 sub get_namespace {
-	my($self, $namespace) = @_;
-	if (! defined $namespace || ! length $namespace) {
-		Throwable::Error->throw(message=>'$namespace cannot be null');
-	}
-	my $namespace_path = $self->base_path . "/namespaces/$namespace";
-	my $res = $self->ua->request($self->create_request(GET => $self->url . $namespace_path));
-	if ($res->is_success) {
-		my $ns = $self->json->decode($res->content);
-		
-		# Somewhere between Kubernetes 1.2 and 1.5, the self link for namespaces broke. So for now, we can't trust them.
-		# to populate the base_path. A bug report indicates that this bug is fixed in 1.7.
-		# https://github.com/kubernetes/kubernetes/issues/48321
-		my(%create_args) = (
-			url             => $self->url, 
-			base_path       => $namespace_path, 
-			server_version  => $self->server_version,
-			api_version     => $self->api_version, 
-			namespace       => $namespace, 
-			_namespace_data => $ns
-		);
-		$create_args{username} = $self->username if(defined $self->username);
-		$create_args{password} = $self->password if(defined $self->password);
-		$create_args{ssl_cert_file} = $self->ssl_cert_file if(defined $self->ssl_cert_file);
-		$create_args{ssl_key_file} = $self->ssl_key_file if(defined $self->ssl_key_file);
-		$create_args{ssl_ca_file} = $self->ssl_ca_file if(defined $self->ssl_ca_file);
-		return Net::Kubernetes::Namespace->new(%create_args);
-	}else{
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error getting namespace $namespace:\n".$res->message);
-	}
+    my ($self, $namespace) = @_;
+    if (!defined $namespace || !length $namespace) {
+        Throwable::Error->throw(message => '$namespace cannot be null');
+    }
+    my $namespace_path = $self->base_path . "/namespaces/$namespace";
+    my $res = $self->ua->request($self->create_request(GET => $self->url . $namespace_path));
+    if ($res->is_success) {
+        my $ns = $self->json->decode($res->content);
+
+        # Somewhere between Kubernetes 1.2 and 1.5, the self link for namespaces broke. So for now, we can't trust them.
+        # to populate the base_path. A bug report indicates that this bug is fixed in 1.7.
+        # https://github.com/kubernetes/kubernetes/issues/48321
+        my (%create_args) = (
+            url             => $self->url,
+            base_path       => $namespace_path,
+            server_version  => $self->server_version,
+            api_version     => $self->api_version,
+            namespace       => $namespace,
+            _namespace_data => $ns
+        );
+        $create_args{username}      = $self->username      if (defined $self->username);
+        $create_args{password}      = $self->password      if (defined $self->password);
+        $create_args{ssl_cert_file} = $self->ssl_cert_file if (defined $self->ssl_cert_file);
+        $create_args{ssl_key_file}  = $self->ssl_key_file  if (defined $self->ssl_key_file);
+        $create_args{ssl_ca_file}   = $self->ssl_ca_file   if (defined $self->ssl_ca_file);
+        return Net::Kubernetes::Namespace->new(%create_args);
+    }
+    else {
+        Net::Kubernetes::Exception->throw(
+            code    => $res->code,
+            message => "Error getting namespace $namespace:\n" . $res->message
+        );
+    }
 }
 
 
 sub list_nodes {
-	my $self = shift;
-	my(%options);
-	if (ref($_[0])) {
-		%options = %{ $_[0] };
-	}else{
-		%options = @_;
-	}
+    my $self = shift;
+    my (%options);
+    if (ref($_[0])) {
+        %options = %{$_[0]};
+    }
+    else {
+        %options = @_;
+    }
 
-	my $uri = URI->new($self->path.'/nodes');
-	my(%form) = ();
-	$form{labelSelector}=$self->build_selector_from_hash($options{labels}) if (exists $options{labels});
-	$form{fieldSelector}=$self->build_selector_from_hash($options{fields}) if (exists $options{fields});
-	$uri->query_form(%form);
+    my $uri = URI->new($self->path . '/nodes');
+    my (%form) = ();
+    $form{labelSelector} = $self->build_selector_from_hash($options{labels}) if (exists $options{labels});
+    $form{fieldSelector} = $self->build_selector_from_hash($options{fields}) if (exists $options{fields});
+    $uri->query_form(%form);
 
-	my $res = $self->ua->request($self->create_request(GET => $uri));
-	if ($res->is_success) {
-		my $node_list = $self->json->decode($res->content);
-		my(@nodes)=();
-		foreach my $node (@{ $node_list->{items}}){
-			$node->{apiVersion} = $node_list->{apiVersion};
-			push @nodes, $self->create_resource_object($node, 'Node');
-		}
-		return wantarray ? @nodes : \@nodes;
-	}else{
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
-	}
+    my $res = $self->ua->request($self->create_request(GET => $uri));
+    if ($res->is_success) {
+        my $node_list = $self->json->decode($res->content);
+        my (@nodes) = ();
+        foreach my $node (@{$node_list->{items}}) {
+            $node->{apiVersion} = $node_list->{apiVersion};
+            push @nodes, $self->create_resource_object($node, 'Node');
+        }
+        return wantarray ? @nodes : \@nodes;
+    }
+    else {
+        Net::Kubernetes::Exception->throw(
+            code    => $res->code,
+            message => $res->message
+        );
+    }
 }
 
 sub get_node {
-	my($self, $name) = @_;
-	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
-	return $self->get_resource_by_name($name, 'node');
+    my ($self, $name) = @_;
+    Net::Kubernetes::Exception->throw(message => "Missing required parameter 'name'") if (!defined $name || !length $name);
+    return $self->get_resource_by_name($name, 'node');
 }
 
 
 sub list_service_accounts {
-	my $self = shift;
-	my(%options);
-	if (ref($_[0])) {
-		%options = %{ $_[0] };
-	}else{
-		%options = @_;
-	}
+    my $self = shift;
+    my (%options);
+    if (ref($_[0])) {
+        %options = %{$_[0]};
+    }
+    else {
+        %options = @_;
+    }
 
-	my $uri = URI->new($self->path.'/serviceaccounts');
-	my(%form) = ();
-	$form{labelSelector}=$self->build_selector_from_hash($options{labels}) if (exists $options{labels});
-	$form{fieldSelector}=$self->build_selector_from_hash($options{fields}) if (exists $options{fields});
-	$uri->query_form(%form);
+    my $uri = URI->new($self->path . '/serviceaccounts');
+    my (%form) = ();
+    $form{labelSelector} = $self->build_selector_from_hash($options{labels}) if (exists $options{labels});
+    $form{fieldSelector} = $self->build_selector_from_hash($options{fields}) if (exists $options{fields});
+    $uri->query_form(%form);
 
-	my $res = $self->ua->request($self->create_request(GET => $uri));
-	if ($res->is_success) {
-		my $sa_list = $self->json->decode($res->content);
-		my(@saccs)=();
-		foreach my $sacc (@{ $sa_list->{items}}){
-			$sacc->{apiVersion} = $sa_list->{apiVersion};
-			push @saccs, $self->create_resource_object($sacc, 'ServiceAccount');
-		}
-		return wantarray ? @saccs : \@saccs;
-	}else{
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
-	}
+    my $res = $self->ua->request($self->create_request(GET => $uri));
+    if ($res->is_success) {
+        my $sa_list = $self->json->decode($res->content);
+        my (@saccs) = ();
+        foreach my $sacc (@{$sa_list->{items}}) {
+            $sacc->{apiVersion} = $sa_list->{apiVersion};
+            push @saccs, $self->create_resource_object($sacc, 'ServiceAccount');
+        }
+        return wantarray ? @saccs : \@saccs;
+    }
+    else {
+        Net::Kubernetes::Exception->throw(
+            code    => $res->code,
+            message => $res->message
+        );
+    }
 }
 
-
 sub _get_default_namespace {
-	my($self) = @_;
-	return $self->get_namespace('default');
+    my ($self) = @_;
+    return $self->get_namespace('default');
 }
 
 # SEEALSO: Net::Kubernetes::Namespace, Net::Kubernetes::Resource
@@ -150,7 +166,7 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -164,7 +180,7 @@ version 1.04
   my @rcs2 = $kube->list_rc();
 
   my @deployments  = $kube->list_deployments();
-  
+
   my @replica_sets  = $keyb->list_replica_sets();
   my @replica_sets2 = $keyb->list_rs();
 
@@ -181,7 +197,13 @@ version 1.04
 
   my $other_pod = $ns->create_from_file('./my-pod.yaml');
 
-=head1 METHODS
+=begin html
+
+<h2>Build Status</h2>
+
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.21" />
+
+=end html
 
 =head2 new - Create a new $kube object
 
@@ -216,7 +238,7 @@ to a file handle (from which to read the token).
 =item ssl_cert_file, ssl_key_file, ssl_ca_file
 
 This there options passed into new will cause Net::Kubernetes in inlcude SSL client certs to requests to the kuberernetes
-API server for authentication.  There are basically just a passthrough to the underlying LWP::UserAgent used to handle the 
+API server for authentication.  There are basically just a passthrough to the underlying LWP::UserAgent used to handle the
 api requests.
 
 =item server_version
@@ -255,14 +277,6 @@ returns a list of L<Net::Kubernetes::Resource::Node>s
 
 returns a list of L<Net::Kubernetes::Resource::Service>s
 
-=begin html
-
-<h2>Build Status</h2>
-
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.21" />
-
-=end html
-
 =head1 AUTHOR
 
 Dave Mueller <dave@perljedi.com>
@@ -307,12 +321,16 @@ L<Net::Kubernetes::Resource|Net::Kubernetes::Resource>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher Pruden Dave Mueller Kevin Johnson
+=for stopwords Chris Reinhardt Christopher Pruden Dave Mueller Kevin Johnson
 
 =over 4
 
 =item *
 
+Chris Reinhardt <creinhardt@liquidweb.com>
+
+=item *
+
 Christopher Pruden <cdpruden@liquidweb.com>
 
 =item *
@@ -325,6 +343,10 @@ Dave Mueller <dmueller@liquidweb.com>
 
 =item *
 
+Kevin <kcavemanj@gmail.com>
+
+=item *
+
 Kevin Johnson <kcavemanj@gmail.com>
 
 =back
