@@ -1,70 +1,76 @@
 package Net::Kubernetes::Resource;
+$Net::Kubernetes::Resource::VERSION = '1.05';
 # ABSTRACT: Base class for all Net::Kubernetes::Resource objects.
-$Net::Kubernetes::Resource::VERSION = '1.04';
+
 use Moose;
 use Clone qw(clone);
 
 with 'Net::Kubernetes::Role::APIAccess';
 
-
-has kind     => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 0,
+has kind => (
+    is       => 'ro',
+    isa      => 'Str',
+    required => 0,
 );
 
 has api_version => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 0,
+    is       => 'ro',
+    isa      => 'Str',
+    required => 0,
 );
 
 has metadata => (
-	is       => 'rw',
-	isa      => 'HashRef',
-	required => 1
+    is       => 'rw',
+    isa      => 'HashRef',
+    required => 1
 );
 
 has namespace => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 0,
+    is       => 'ro',
+    isa      => 'Str',
+    required => 0,
 );
 
 
 sub delete {
-	my($self) = @_;
-	my($res) = $self->ua->request($self->create_request(DELETE => $self->path));
-	if ($res->is_success) {
-		return 1;
-	}
-	return 0;
+    my ($self) = @_;
+    my ($res) = $self->ua->request($self->create_request(DELETE => $self->path));
+    if ($res->is_success) {
+        return 1;
+    }
+    return 0;
 }
 
 sub update {
-	my($self) = @_;
-	my($res) = $self->ua->request($self->create_request(PUT => $self->path, undef, $self->json->encode($self->as_hashref)));
-	if ($res->is_success) {
-		return 1;
-	}
-	return 0;
+    my ($self) = @_;
+    my ($res)  = $self->ua->request(
+        $self->create_request(
+            PUT => $self->path,
+            undef, $self->json->encode($self->as_hashref)
+        )
+    );
+    if ($res->is_success) {
+        return 1;
+    }
+    return 0;
 }
 
-sub as_hashref
-{
-	my($self) = @_;
+sub as_hashref {
+    my ($self) = @_;
 
-        # It is possible for kuberentes to churn the resource version higher even if
-        # you just refresh it and then attempt an update operation. Let's ignore it for now.
-        my $metadata = $self->metadata;
-        delete $metadata->{resourceVersion};
+    # It is possible for kuberentes to churn the resource version higher even if
+    # you just refresh it and then attempt an update operation. Let's ignore it for now.
+    my $metadata = $self->metadata;
+    delete $metadata->{resourceVersion};
 
-	return clone({
-		inner(),
-		apiVersion=>$self->api_version,
-		kind=>$self->kind,
-		metadata=>$self->metadata
-	});
+    return clone(
+        {
+            inner(),
+            apiVersion => $self->api_version,
+            kind       => $self->kind,
+            metadata   => $self->metadata
+        }
+    );
 }
 
 return 42;
@@ -81,9 +87,7 @@ Net::Kubernetes::Resource - Base class for all Net::Kubernetes::Resource objects
 
 =head1 VERSION
 
-version 1.04
-
-=head1 METHODS
+version 1.05
 
 =head2 $resource->delete
 
