@@ -1,6 +1,7 @@
 package Net::Kubernetes::Resource::Pod;
+$Net::Kubernetes::Resource::Pod::VERSION = '1.05';
 # ABSTRACT: Object representatioon of a Kubernetes Pod
-$Net::Kubernetes::Resource::Pod::VERSION = '1.04';
+
 use Moose;
 
 extends 'Net::Kubernetes::Resource';
@@ -10,17 +11,20 @@ with 'Net::Kubernetes::Resource::Role::Spec';
 
 
 sub logs {
-	my($self, %options) = @_;
-	if (scalar(@{ $self->spec->{containers} }) > 1 && ! exists($options{container})) {
-		Net::Kunbernetes::Exception::ClientException->throw(code=>499,  message=>'Must provide container to get logs from a multi-container pod');
-	}
-	
-	my $uri = URI->new($self->path.'/log');
-	$uri->query_form(\%options);	
-	my $res = $self->ua->request($self->create_request(GET => $uri));
-	if ($res->is_success) {
-		return $res->content;
-	}
+    my ($self, %options) = @_;
+    if (scalar(@{$self->spec->{containers}}) > 1 && !exists($options{container})) {
+        Net::Kunbernetes::Exception::ClientException->throw(
+            code    => 499,
+            message => 'Must provide container to get logs from a multi-container pod'
+        );
+    }
+
+    my $uri = URI->new($self->path . '/log');
+    $uri->query_form(\%options);
+    my $res = $self->ua->request($self->create_request(GET => $uri));
+    if ($res->is_success) {
+        return $res->content;
+    }
 }
 
 return 42;
@@ -37,9 +41,7 @@ Net::Kubernetes::Resource::Pod - Object representatioon of a Kubernetes Pod
 
 =head1 VERSION
 
-version 1.04
-
-=head1 METHODS
+version 1.05
 
 =head2 logs([container=>'foo'])
 
