@@ -1,6 +1,7 @@
 package Net::Kubernetes::Resource::Secret;
+$Net::Kubernetes::Resource::Secret::VERSION = '1.05';
 # ABSTRACT: Object representatioon of a Kubernetes Secret
-$Net::Kubernetes::Resource::Secret::VERSION = '1.04';
+
 use Moose;
 
 use File::Slurp qw(write_file);
@@ -9,44 +10,46 @@ use MIME::Base64 qw(decode_base64);
 extends 'Net::Kubernetes::Resource';
 
 has type => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 1
+    is       => 'ro',
+    isa      => 'Str',
+    required => 1
 );
 
 has data => (
-	is       => 'ro',
-	isa      => 'HashRef',
-	required => 1
+    is       => 'ro',
+    isa      => 'HashRef',
+    required => 1
 );
 
 
 sub render {
     my $self = shift;
 
-    my(%args);
+    my (%args);
     if (ref($_[0])) {
-        %args = %{ $_[0] };
-    } else {
+        %args = %{$_[0]};
+    }
+    else {
         %args = @_;
     }
 
     $args{force} //= 0;
 
-    if (! -d $args{directory}) {
+    if (!-d $args{directory}) {
         Throwable::Error->throw(message => "Directory must exist: $args{directory}");
     }
 
     for my $file (keys %{$self->data}) {
-        write_file("$args{directory}/$file",
-            {
+        write_file(
+            "$args{directory}/$file", {
                 err_mode   => 'croak',
                 no_clobber => !$args{force},
-				binmode => ':raw',
+                binmode    => ':raw',
             },
             decode_base64 ${$self->data}{$file}
         );
     }
+
     # if we didn't write them all, we better have thrown an exception.
     return scalar keys %{$self->data};
 }
@@ -65,9 +68,7 @@ Net::Kubernetes::Resource::Secret - Object representatioon of a Kubernetes Secre
 
 =head1 VERSION
 
-version 1.04
-
-=head1 METHODS
+version 1.05
 
 =head2 render(directory => "/path/to/write/secret/files", [ force => 0/] )
 
