@@ -1,6 +1,7 @@
 package Net::Kubernetes::Role::ResourceFetcher;
+$Net::Kubernetes::Role::ResourceFetcher::VERSION = '1.05';
 # ABSTRACT: Role to give access to get_* methods.
-$Net::Kubernetes::Role::ResourceFetcher::VERSION = '1.04';
+
 use Moose::Role;
 use MooseX::Aliases;
 use syntax "try";
@@ -12,23 +13,25 @@ with 'Net::Kubernetes::Role::ResourceFactory';
 with 'Net::Kubernetes::Role::ResourceCatalog';
 
 sub get_resource_by_name {
-	my($self, $name, $type) = @_;
-	my $resource_path = $self->get_resource_path(lc($type));
-	my($res) = $self->ua->request($self->create_request(GET => "$resource_path/$name"));
-	if ($res->is_success) {
-		return $self->create_resource_object($self->json->decode($res->content));
-	}
-	else {
-		my $message;
-		try{
-			my $obj = $self->json->decode($res->content);
-			$message = $obj->{message};
-		}
-		catch($e) {
-			$message = $res->message;
-		}
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$message);
-	}
+    my ($self, $name, $type) = @_;
+    my $resource_path = $self->get_resource_path(lc($type));
+    my ($res) = $self->ua->request($self->create_request(GET => "$resource_path/$name"));
+    if ($res->is_success) {
+        return $self->create_resource_object($self->json->decode($res->content));
+    }
+    else {
+        my $message;
+        try {
+            my $obj = $self->json->decode($res->content);
+            $message = $obj->{message};
+        }
+        catch($e) {
+            $message = $res->message;
+            } Net::Kubernetes::Exception->throw(
+            code    => $res->code,
+            message => $message
+            );
+    }
 }
 
 return 42;
@@ -45,7 +48,7 @@ Net::Kubernetes::Role::ResourceFetcher - Role to give access to get_* methods.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 AUTHOR
 
