@@ -1,6 +1,7 @@
 package Net::Kubernetes::Role::ResourceLister;
+$Net::Kubernetes::Role::ResourceLister::VERSION = '1.05';
 # ABSTRACT: Role to give access to list_* methods.
-$Net::Kubernetes::Role::ResourceLister::VERSION = '1.04';
+
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -16,48 +17,48 @@ requires 'json';
 
 
 sub list_pods {
-	my $self = shift;
-	return $self->_retrieve_list('Pod', @_);
+    my $self = shift;
+    return $self->_retrieve_list('Pod', @_);
 }
 
 
 sub list_replication_controllers {
-	my $self = shift;
-	return $self->_retrieve_list('ReplicationController', @_);
+    my $self = shift;
+    return $self->_retrieve_list('ReplicationController', @_);
 }
 
 alias list_rc => 'list_replication_controllers';
 
 
 sub list_services {
-	my $self = shift;
-	return $self->_retrieve_list('Service', @_);
+    my $self = shift;
+    return $self->_retrieve_list('Service', @_);
 }
 
 
 sub list_events {
-	my $self = shift;
-	return $self->_retrieve_list('Event', @_);
+    my $self = shift;
+    return $self->_retrieve_list('Event', @_);
 }
 
 
 sub list_secrets {
-	my $self = shift;
-	return $self->_retrieve_list('Secret', @_);
+    my $self = shift;
+    return $self->_retrieve_list('Secret', @_);
 }
 
 
 sub list_endpoints {
-	my $self = shift;
-	return $self->_retrieve_list('Endpoint', @_);
+    my $self = shift;
+    return $self->_retrieve_list('Endpoint', @_);
 }
 
 
 sub list_deployments {
-	my $self = shift;
-	my %options = $self->_norm_options(@_);
+    my $self    = shift;
+    my %options = $self->_norm_options(@_);
 
-	return $self->_retrieve_list('Deployment', %options);
+    return $self->_retrieve_list('Deployment', %options);
 }
 
 
@@ -65,50 +66,55 @@ sub list_deployments {
 alias list_rs => 'list_replica_sets';
 
 sub list_replica_sets {
-	my $self = shift;
-	my %options = $self->_norm_options(@_);
+    my $self    = shift;
+    my %options = $self->_norm_options(@_);
 
-	return $self->_retrieve_list('ReplicaSet', %options);
+    return $self->_retrieve_list('ReplicaSet', %options);
 }
 
 sub _retrieve_list {
-	my $self = shift;
-	my $resource_kind = shift;
-	my %options = $self->_norm_options(@_);
+    my $self          = shift;
+    my $resource_kind = shift;
+    my %options       = $self->_norm_options(@_);
 
-	my $uri = URI->new($self->get_resource_path($resource_kind));
-	my(%form) = ();
-	$form{labelSelector}=$self->build_selector_from_hash($options{labels}) if (exists $options{labels});
-	$form{fieldSelector}=$self->build_selector_from_hash($options{fields}) if (exists $options{fields});
-	$uri->query_form(%form);
+    my $uri = URI->new($self->get_resource_path($resource_kind));
+    my (%form) = ();
+    $form{labelSelector} = $self->build_selector_from_hash($options{labels}) if (exists $options{labels});
+    $form{fieldSelector} = $self->build_selector_from_hash($options{fields}) if (exists $options{fields});
+    $uri->query_form(%form);
 
-	my $res = $self->ua->request($self->create_request(GET => $uri));
-	if ($res->is_success) {
-		my $resource_list = $self->json->decode($res->content);
+    my $res = $self->ua->request($self->create_request(GET => $uri));
+    if ($res->is_success) {
+        my $resource_list = $self->json->decode($res->content);
 
-		my @resources;
-		foreach my $resource (@{ $resource_list->{items}}){
-			$resource->{apiVersion} = $resource_list->{apiVersion};
-			push @resources, $self->create_resource_object($resource, $resource_kind);
-		}
+        my @resources;
+        foreach my $resource (@{$resource_list->{items}}) {
+            $resource->{apiVersion} = $resource_list->{apiVersion};
+            push @resources, $self->create_resource_object($resource, $resource_kind);
+        }
 
-		return wantarray ? @resources : \@resources;
-	}else{
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
-	}
+        return wantarray ? @resources : \@resources;
+    }
+    else {
+        Net::Kubernetes::Exception->throw(
+            code    => $res->code,
+            message => $res->message
+        );
+    }
 }
 
 sub _norm_options {
-	my $self = shift;
-	my %options;
+    my $self = shift;
+    my %options;
 
-	if (ref($_[0])) {
-		%options = %{ $_[0] };
-	}else{
-		%options = @_;
-	}
+    if (ref($_[0])) {
+        %options = %{$_[0]};
+    }
+    else {
+        %options = @_;
+    }
 
-	return %options;
+    return %options;
 }
 
 return 42;
@@ -125,9 +131,7 @@ Net::Kubernetes::Role::ResourceLister - Role to give access to list_* methods.
 
 =head1 VERSION
 
-version 1.04
-
-=head1 METHODS
+version 1.05
 
 =head2 list_pods([label=>{label=>value}], [fields=>{field=>value}])
 
